#
# spec file for package nss_wrapper
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


############################# NOTE ##################################
#
# This is a special library. You are not able to link this library.
# Do NOT create library package or a devel package!
#
############################# NOTE ##################################
Name:           nss_wrapper
Version:        1.1.15
Release:        3.5
Summary:        A wrapper for the user, group and hosts NSS API
License:        BSD-3-Clause
Group:          Development/Libraries/C and C++
URL:            https://cwrap.org/
Source0:        https://ftp.samba.org/pub/cwrap/%{name}-%{version}.tar.gz
Source1:        https://ftp.samba.org/pub/cwrap/%{name}-%{version}.tar.gz.asc
Source2:        https://cryptomilk.org/gpgkey-8DFF53E18F2ABC8D8F3C92237EE0FC4DCC014E3D.gpg#/%{name}.keyring
Source3:        %{name}-rpmlintrc
Patch0:         nss_wrapper-fix-cmocka-1.1.6+-support.patch
BuildRequires:  cmake
BuildRequires:  libcmocka-devel
BuildRequires:  netcfg libnss_usrfiles2
Recommends:     cmake
Recommends:     pkgconf

%description
There are projects which provide daemons that need to be able to create, modify
and delete Unix users, or just switch user IDs to interact with the system, e.g.
a user space file server. To be able to test that, you need the privilege to
modify the passwd and groups files. With nss_wrapper, it is possible to define
your own passwd and groups files which will be used by software to act correctly
while under test.

If you have a client and server under test, they normally use functions to
resolve network names to addresses (DNS) or vice versa. The nss_wrappers allow
you to create a hosts file to setup name resolution for the addresses you use
with socket_wrapper.

To use it, set the following environment variables:

LD_PRELOAD=libuid_wrapper.so
NSS_WRAPPER_PASSWD=/path/to/passwd
NSS_WRAPPER_GROUP=/path/to/group
NSS_WRAPPER_HOSTS=/path/to/host

This package does not have a devel package, because this project is for
development/testing.

%prep
%autosetup -p1

%build
%cmake \
  -DUNIT_TESTING=ON

%make_build VERBOSE=1

%install
%cmake_install

find %{buildroot}%{_bindir} -name "*.pl" \
    | xargs sed -i '1 s|/usr/bin/env\ perl|/usr/bin/perl|'

%check
%ctest

%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig

%files
%doc AUTHORS README.md CHANGELOG
%license LICENSE
%{_bindir}/nss_wrapper.pl
%{_libdir}/libnss_wrapper.so*
%dir %{_libdir}/cmake/nss_wrapper
%{_libdir}/cmake/nss_wrapper/nss_wrapper-config-version.cmake
%{_libdir}/cmake/nss_wrapper/nss_wrapper-config.cmake
%{_libdir}/pkgconfig/nss_wrapper.pc
%{_mandir}/man1/nss_wrapper.1%{?ext_man}

%changelog
* Thu Mar  2 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Actually apply nss_wrapper-fix-cmocka-1.1.6+-support.patch (use
  autosetup instead of setup).
* Mon Feb 27 2023 Andreas Schneider <asn@cryptomilk.org>
- Fix building with cmocka >= 1.1.6
  * Added nss_wrapper-fix-cmocka-1.1.6+-support.patch
* Wed Jan 25 2023 Andreas Schneider <asn@cryptomilk.org>
- Update to version 1.1.15
  * Fixed linking issue in tests
  * Fixed a memory leak in tests
* Wed Jan 25 2023 Andreas Schneider <asn@cryptomilk.org>
- Update to version 1.1.14
  * Fixed implementation of initgroups()
  * Fixed implementation of getgrouplist()
  * Avoid dclose(RTLD_NEXT)
* Wed Nov  9 2022 Andreas Schneider <asn@cryptomilk.org>
- Update to version 1.1.13
  * Fixed possible mutex and threading issues
* Fri Jun 24 2022 Andreas Schneider <asn@cryptomilk.org>
- Update to version 1.1.12
  * Added (de)contructor support on AIX with pragma init/finish
  * Fixed possible crash in getaddrinfo()
  * Fixed issues with processes closing all fds when forking
  * Fixed issues with setgrent() and endpwent() nss module support
* Wed Apr  7 2021 Dirk Müller <dmueller@suse.com>
- avoid filelist from filesystem package
* Wed Mar 31 2021 Andreas Schneider <asn@cryptomilk.org>
- Update to version 1.1.11
  * https://gitlab.com/cwrap/nss_wrapper/-/blob/nss_wrapper-1.1.11/CHANGELOG
* Thu Mar 19 2020 Andreas Schneider <asn@cryptomilk.org>
- Update to version 1.1.10
  * Fixed crash bug in OpenLDAP libraries with gethostbyname_r()
  * Code cleanup in gethostbyname(2)(_r) functions
* Mon Mar 16 2020 Andreas Schneider <asn@cryptomilk.org>
- Update to version 1.1.9
  * Fixed log spam when loading modules
* Mon Feb 17 2020 Andreas Schneider <asn@cryptomilk.org>
- Update to version 1.1.8
  * Fixed path to library in nss_wrapper.pc
  * Try different backends for gethostbyaddr nd gethostbyname
* Wed Nov 13 2019 Andreas Schneider <asn@cryptomilk.org>
- Update to version 1.1.7
  * Added NSS_WRAPPER_DISABLE_DEEPBIND env variable
  * Improvded logging
  * Fixed location in cmake config
* Wed Aug 21 2019 Andreas Schneider <asn@cryptomilk.org>
- Change Requires to Recommends for cmake and pkgconf
* Fri May 17 2019 Andreas Schneider <asn@cryptomilk.org>
- Update to version 1.1.6
  * Fixed issues with memory alignment of getgrnam()
  * Fixed getpwnam() on FreeBSD
  * Started to use modern cmake (>= 3.5.0)
* Wed Oct 31 2018 Andreas Schneider <asn@cryptomilk.org>
- Update to version 1.1.5
  * Fixed running on older distributions
* Wed Oct 31 2018 Andreas Schneider <asn@cryptomilk.org>
- Update to version 1.1.4
  * Fixed module getpw* functions
  * Fixed nss_wrapper.pl to use correct perl binary
  * Fixed compatibility with musl-libc
* Mon Mar 21 2016 asn@cryptomilk.org
- Update to version 1.1.3
  * Added support for BSD 'struct passwd' members
  * Replaced strcpy() with snprintf()
* Sun Feb 14 2016 jengelh@inai.de
- Editorial fixes to the description
- Use %%_smp_mflags for parallel build instead
* Thu Jan 14 2016 asn@cryptomilk.org
- Update to version 1.1.2
  * Fixed segfault while reloading hosts file
  * Fixed issue where are not fault tolerant if an alias has already
    been added
  * Fixed nss_wrapper build on Solaris
* Fri Nov 20 2015 asn@cryptomilk.org
- Update to version 1.1.0
  * Added support for initgroups()
  * Added support for shadow files (getspnam(), etc.)
  * Improved support for multi address handling in getaddrinfo()
  * Improved file parser
  * Fixed compilation on machines without IPv4 support
  * Fixed service string sanity check in getaddrinfo() (bso #11501)
  * Fixed AI_NUMERICHOST handling in getaddrinfo() (bso # 11477)
* Wed Jun  3 2015 mpluskal@suse.com
- Rename rpmlintrc to match packaging guidelines
- Add rpmlintrc as source
* Mon May 11 2015 asn@cryptomilk.org
- Cleanup specfile
* Thu Sep 11 2014 asn@cryptomilk.org
- Update to version 1.0.3.
  * Added a nss_wrapper manpage.
  * Fixed cmake find_package configs.
  * Fixed resolving hostnames with a trailing dot.
  * Fixed an overflow when checking if a IPv6 address is IPv4.
  * Fall back to RTLD_NEXT for symbol binding if we can't find libc.
* Thu Feb 13 2014 asn@cryptomilk.org
- Initial package.
